@@ -88,7 +88,6 @@ def status(
     cache_odb: Optional["HashFileDB"] = None,
     shallow: bool = True,
     jobs: Optional[int] = None,
-    **kwargs,
 ) -> "StatusResult":
     """Return status of whether or not the specified objects exist odb.
 
@@ -162,6 +161,7 @@ def compare_status(
     check_deleted: bool = True,
     src_index: Optional["ObjectDBIndexBase"] = None,
     dest_index: Optional["ObjectDBIndexBase"] = None,
+    cache_odb: Optional["HashFileDB"] = None,
     jobs: Optional[int] = None,
     **kwargs,
 ) -> "CompareStatusResult":
@@ -173,10 +173,15 @@ def compare_status(
         new: hashes that only exist in src
         deleted: hashes that only exist in dest
     """
-    if "cache_odb" not in kwargs:
-        kwargs["cache_odb"] = src
+    if cache_odb is None:
+        cache_odb = src
     dest_exists, dest_missing = status(
-        dest, obj_ids, index=dest_index, jobs=jobs, **kwargs
+        dest,
+        obj_ids,
+        index=dest_index,
+        jobs=jobs,
+        cache_odb=cache_odb,
+        **kwargs,
     )
     # for transfer operations we can skip src status check when all objects
     # already exist in dest
